<?php
/**
 * Testimonial Section widget.
 */


if( ! class_exists('Prasoon_Testimonial_Section_Widget')) :

class Prasoon_Testimonial_Section_Widget extends WP_Widget {
	/**
	 * Register widget with WordPress.
	 */
	function __construct() {
		parent::__construct(
			'pr_testimonial_widget', // Base ID
			__( 'Prasoon: Testimonial Section', 'prasoon' ), // Name
			array( 'description' => __( 'Note: This widget will be removed in upper versions. Please use the new testimonial widget', 'prasoon' ), ) // Args
		);
	}

	/**
	 * Front-end display of widget.
	 *
	 * @see WP_Widget::widget()
	 *
	 * @param array $args     Widget arguments.
	 * @param array $instance Saved values from database.
	 */
	public function widget( $args, $instance ) {
		extract( $args );

		$image = ! empty( $instance['image'] ) ? $instance['image'] : '';
		$nop = ! empty( $instance['nop'] ) ? $instance['nop'] : '';


		$options = array(
        'post_type' => 'testimonial',
        'posts_per_page' => $nop,
    );
    $query = new WP_Query( $options );
    // run the loop based on the query
    if ( $query->have_posts() ) { ?>
			<section id="testimonials">
        <div class="cover-testimonial" style="background: url(<?php echo esc_url($image); ?>) no-repeat;"><div class="cover-testimonial-overlay"></div>
          <div class="testimonial-section wow fadeInUp" data-wow-duration="4s">
            <div class="container">
                    <div id="text-carousel" class="carousel slide" data-ride="carousel">
                      <!-- Wrapper for slides -->
                      <div class="row">
                          <div class="col-md-12">
                              <div class="carousel-inner">
      							<?php
								    while ( $query->have_posts() ) {
								        $query->the_post();
								  		$postid = get_the_ID();
								?>
									<div class="item">
										<div class="content">
											<div class="carousel-content">
												<div class="quote"></div>
												<p><?php the_content(); ?></p>
												<div class="client-image">
													<?php the_post_thumbnail('small'); ?>
													<h3><?php echo get_post_meta( $postid, 'client_name', true ); ?></h3>
												</div>
											</div>
										</div>
									</div>
									<?php
 					               }?>
                    			</div>
              				</div>
          				</div>
												<!-- Controls -->
                      <a class="left carousel-control" href="#text-carousel" data-slide="prev">
                        <span class="glyphicon glyphicon-chevron-left"></span>
                      </a>
                      <a class="right carousel-control" href="#text-carousel" data-slide="next">
                        <span class="glyphicon glyphicon-chevron-right"></span>
                      </a>
                  </div>
            </div>
          </div>
        </div>
      </section>

       <?php
      }

	}

	/**
	 * Back-end widget form.
	 *
	 * @see WP_Widget::form()
	 *
	 * @param array $instance Previously saved values from database.
	 */
	public function form( $instance ) {
	$image = ! empty( $instance['image'] ) ? $instance['image'] : '';
    $nop = ! empty( $instance['nop'] ) ? $instance['nop'] : '';
    ?>

    	<p>
        	<label for="<?php echo $this->get_field_name( 'image' ); ?>"><?php _e( 'Background Image Url:','prasoon'); ?></label>
        	<input name="<?php echo $this->get_field_name( 'image' ); ?>" id="<?php echo $this->get_field_id( 'image' ); ?>" class="widefat" type="text" size="36"  value="<?php echo esc_url( $image ); ?>" />        
    	</p>

		<p>
        	<label for="<?php echo $this->get_field_id('nop'); ?>"><?php _e('Number of posts:','prasoon'); ?></label>
        	<input class="widefat" id="<?php echo $this->get_field_id('nop'); ?>" name="<?php echo $this->get_field_name('nop'); ?>" type="text" value="<?php echo $nop; ?>" />
    	</p>
    <?php
	}

	/**
	 * Sanitize widget form values as they are saved.
	 *
	 * @see WP_Widget::update()
	 *
	 * @param array $new_instance Values just sent to be saved.
	 * @param array $old_instance Previously saved values from database.
	 *
	 * @return array Updated safe values to be saved.
	 */
	public function update( $new_instance, $old_instance ) {
		$instance = $old_instance;
		$instance['image']  = strip_tags( $new_instance['image'] );
    	$instance['nop']   = wp_filter_post_kses($new_instance['nop']);

    return $instance;
	}

}
endif;



if( ! function_exists('register_prasoon_testimonial_section_widget')) :
// register widget
function register_prasoon_testimonial_section_widget() {
    register_widget( 'Prasoon_Testimonial_Section_Widget' );
}
endif;


add_action( 'widgets_init', 'register_prasoon_testimonial_section_widget' );
